<p align="center">
  <!-- <a href="https://vt-hacks-live-site.netlify.app/" target="_blank" >
    <img alt="VTHacks" src="https://vt-hacks-live-site.netlify.app/LogoFinal.svg" width="180" />
  </a> -->
</p>
<h1 align="center">
  StartMyProject
</h1>
StartMyProject is an open source tool that gives a quick way for developers to start their workspaces. This way, developers get to spend more time coding and less time starting up their development environments

## How to use StartMyProject

1. **Create a Shortcut/Alias to the `execute`file(optional)**
   Creating a desktop shortcut is the recommended way to start the application

2. **Execute**
   Executing the .bat or .sh file (for windows or macOS/linux respectively) will start the application and perform first time start up

3. **Tweak Settings and add Projects**
   Each project will require an absolute path to where it is installed on your machine. Configure IDE start up by providing the arguments to start your code editor on the terminal.
4. **Provide Feedback**
   Please send any feedback, constructive criticism, and feature requests to [jacobmillerdev@gmail.com](mailto:jacobmillerdev@gmail.com).

<p align="center">
    <a href="https://jacobmiller22.com">Jacob Miller</a>
</p>
